@@ -13,7 +13,7 @@
 ##############################################################################
 """Form and Widget Framework Interfaces
 
-$Id: interfaces.py 114046 2010-07-01 12:00:21Z jfroche $
+$Id: interfaces.py 118858 2010-12-14 09:36:13Z rogerineichen $
 """
 __docformat__ = "reStructuredText"
 import zope.i18nmessageid
@@ -21,7 +21,6 @@ import zope.interface
 import zope.schema
 from zope.interface.common import mapping
 from zope.location.interfaces import ILocation
-from zope.publisher.interfaces.browser import IBrowserRequest
 
 MessageFactory = _ = zope.i18nmessageid.MessageFactory('z3c.form')
 
@@ -43,11 +42,15 @@ NOVALUE = NO_VALUE
 
 # ----[ Layer Declaration ]--------------------------------------------------
 
-class IFormLayer(IBrowserRequest):
+class IFormLayer(zope.interface.Interface):
     """A layer that contains all registrations of this package.
 
     It is intended that someone can just use this layer as a base layer when
     using this package.
+    
+    Since version 2.4.2, this layer doesn't provide IBrowserRequst anymore.
+    This makes it possible to use the IFormLayer within z3c.jsonrpc without
+    to apply the IBrowserRequest into the jsonrpc request. 
     """
 
 
